@@ -4,9 +4,7 @@ use parent 'App::Office::Contacts';
 use strict;
 use utf8;
 use warnings;
-use warnings  qw(FATAL utf8);    # Fatalize encoding glitches.
-use open      qw(:std :utf8);    # Undeclared streams in UTF-8.
-use charnames qw(:full :short);  # Unneeded in v5.16.
+use warnings  qw(FATAL utf8); # Fatalize encoding glitches.
 
 use App::Office::Contacts::Database;
 use App::Office::Contacts::Util::Logger;
@@ -14,7 +12,7 @@ use App::Office::Contacts::View;
 
 # We don't use Moo because we isa CGI::Snapp.
 
-our $VERSION = '2.01';
+our $VERSION = '2.02';
 
 # -----------------------------------------------
 
