@@ -3,9 +3,7 @@ package App::Office::Contacts::Controller::Exporter::Note;
 use strict;
 use utf8;
 use warnings;
-use warnings  qw(FATAL utf8);    # Fatalize encoding glitches.
-use open      qw(:std :utf8);    # Undeclared streams in UTF-8.
-use charnames qw(:full :short);  # Unneeded in v5.16.
+use warnings  qw(FATAL utf8); # Fatalize encoding glitches.
 
 use App::Office::Contacts::Util::Validator;
 
@@ -25,7 +23,7 @@ use Sub::Exporter -setup =>
 
 use Try::Tiny;
 
-our $VERSION = '2.01';
+our $VERSION = '2.02';
 
 # -----------------------------------------------
 
@@ -80,7 +78,7 @@ sub add
 		$response = $self -> param('system_error');
 	};
 
-	return encode('utf8', $response);
+	return encode('utf-8', $response);
 
 } # End of add.
 
@@ -147,7 +145,7 @@ sub delete
 		$response = $self -> param('system_error');
 	};
 
-	return encode('utf8', $response);
+	return encode('utf-8', $response);
 
 } # End of delete.
 
@@ -238,7 +236,7 @@ sub update
 		$response = $self -> param('system_error');
 	};
 
-	return encode('utf8', $response);
+	return encode('utf-8', $response);
 
 } # End of update.
 
@@ -282,7 +280,7 @@ Each instance of this class is an L<App::Office::Contacts::Controller>-based obj
 
 This is a run mode for Note.
 
-See htdocs/assets/templates/app/office/contacts/web.page.tx for the calling code.
+See htdocs/assets/templates/app/office/contacts/homepage.tx for the calling code.
 
 =head2 cgiapp_init()
 
@@ -292,19 +290,19 @@ Provides L<CGI::Snapp> with the list of run modes.
 
 This is a run mode for Note.
 
-See htdocs/assets/templates/app/office/contacts/web.page.tx for the calling code.
+See htdocs/assets/templates/app/office/contacts/homepage.tx for the calling code.
 
 =head2 get_notes($result)
 
 This is a run mode for Note.
 
-See htdocs/assets/templates/app/office/contacts/web.page.tx for the calling code.
+See htdocs/assets/templates/app/office/contacts/homepage.tx for the calling code.
 
 =head2 update()
 
 This is a run mode for Note.
 
-See htdocs/assets/templates/app/office/contacts/web.page.tx for the calling code.
+See htdocs/assets/templates/app/office/contacts/homepage.tx for the calling code.
 
 =head1 FAQ
 
