@@ -3,9 +3,7 @@ package App::Office::Contacts::Controller::Exporter::Organization;
 use strict;
 use utf8;
 use warnings;
-use warnings  qw(FATAL utf8);    # Fatalize encoding glitches.
-use open      qw(:std :utf8);    # Undeclared streams in UTF-8.
-use charnames qw(:full :short);  # Unneeded in v5.16.
+use warnings  qw(FATAL utf8); # Fatalize encoding glitches.
 
 use App::Office::Contacts::Util::Validator;
 
@@ -26,7 +24,7 @@ use Sub::Exporter -setup =>
 
 use Try::Tiny;
 
-our $VERSION = '2.01';
+our $VERSION = '2.02';
 
 # -----------------------------------------------
 
@@ -80,7 +78,7 @@ sub add
 
 	$self -> log(debug => 'Run mode response: ' . ($response =~ /^Error/ ? $response : 'OK') );
 
-	return encode('utf8', $response);
+	return encode('utf-8', $response);
 
 } # End of add.
 
@@ -153,7 +151,7 @@ sub delete
 
 	$self -> log(debug => 'Run mode response: ' . ($response =~ /^Error/ ? $response : 'OK') );
 
-	return encode('utf8', $response);
+	return encode('utf-8', $response);
 
 } # End of delete.
 
@@ -213,7 +211,7 @@ sub display
 
 	$self -> log(debug => 'Run mode response: ' . ($response =~ /^Error/ ? $response : 'OK') );
 
-	return encode('utf8', $response);
+	return encode('utf-8', $response);
 
 } # End of display.
 
@@ -271,7 +269,7 @@ sub get_staff
 		$response = $self -> param('system_error');
 	};
 
-	return encode('utf8', $response);
+	return encode('utf-8', $response);
 
 } # End of get_staff.
 
@@ -329,7 +327,7 @@ sub update
 
 	$self -> log(debug => 'Run mode response: ' . ($response =~ /^Error/ ? $response : 'OK') );
 
-	return encode('utf8', $response);
+	return encode('utf-8', $response);
 
 } # End of update.
 
@@ -373,7 +371,7 @@ Each instance of this class is an L<App::Office::Contacts::Controller>-based obj
 
 This is a run mode for Organization.
 
-See htdocs/assets/templates/app/office/contacts/web.page.tx for the calling code.
+See htdocs/assets/templates/app/office/contacts/homepage.tx for the calling code.
 
 =head2 cgiapp_init()
 
@@ -383,25 +381,25 @@ Provides L<CGI::Snapp> with the list of run modes.
 
 This is a run mode for Organization.
 
-See htdocs/assets/templates/app/office/contacts/web.page.tx for the calling code.
+See htdocs/assets/templates/app/office/contacts/homepage.tx for the calling code.
 
 =head2 display()
 
 This is a run mode for Organization.
 
-See htdocs/assets/templates/app/office/contacts/web.page.tx for the calling code.
+See htdocs/assets/templates/app/office/contacts/homepage.tx for the calling code.
 
 =head2 get_staff()
 
 This is a run mode for Organization.
 
-See htdocs/assets/templates/app/office/contacts/web.page.tx for the calling code.
+See htdocs/assets/templates/app/office/contacts/homepage.tx for the calling code.
 
 =head2 update()
 
 This is a run mode for Organization.
 
-See htdocs/assets/templates/app/office/contacts/web.page.tx for the calling code.
+See htdocs/assets/templates/app/office/contacts/homepage.tx for the calling code.
 
 =head1 FAQ
 
