@@ -3,9 +3,7 @@ package App::Office::Contacts::Controller::Exporter::Person;
 use strict;
 use utf8;
 use warnings;
-use warnings  qw(FATAL utf8);    # Fatalize encoding glitches.
-use open      qw(:std :utf8);    # Undeclared streams in UTF-8.
-use charnames qw(:full :short);  # Unneeded in v5.16.
+use warnings  qw(FATAL utf8); # Fatalize encoding glitches.
 
 use App::Office::Contacts::Util::Validator;
 
@@ -26,7 +24,7 @@ use Sub::Exporter -setup =>
 
 use Try::Tiny;
 
-our $VERSION = '2.01';
+our $VERSION = '2.02';
 
 # -----------------------------------------------
 
@@ -82,7 +80,7 @@ sub add
 		$response = $self -> param('system_error');
 	};
 
-	return encode('utf8', $response);
+	return encode('utf-8', $response);
 
 } # End of add.
 
@@ -157,7 +155,7 @@ sub delete
 		$response = $self -> param('system_error');
 	};
 
-	return encode('utf8', $response);
+	return encode('utf-8', $response);
 
 } # End of delete.
 
@@ -219,7 +217,7 @@ sub display
 		$response = $self -> param('system_error');
 	};
 
-	return encode('utf8', $response);
+	return encode('utf-8', $response);
 
 } # End of display.
 
@@ -277,7 +275,7 @@ sub get_occupations
 		$response = $self -> param('system_error');
 	};
 
-	return encode('utf8', $response);
+	return encode('utf-8', $response);
 
 } # End of get_occupations.
 
@@ -340,7 +338,7 @@ sub update
 		$response = $self -> param('system_error');
 	};
 
-	return encode('utf8', $response);
+	return encode('utf-8', $response);
 
 } # End of update.
 
@@ -384,7 +382,7 @@ item o (None)
 
 This is a run mode for Person.
 
-See htdocs/assets/templates/app/office/contacts/web.page.tx for the calling code.
+See htdocs/assets/templates/app/office/contacts/homepage.tx for the calling code.
 
 =head2 cgiapp_init()
 
@@ -394,25 +392,25 @@ Provides L<CGI::Snapp> with the list of run modes.
 
 This is a run mode for Person.
 
-See htdocs/assets/templates/app/office/contacts/web.page.tx for the calling code.
+See htdocs/assets/templates/app/office/contacts/homepage.tx for the calling code.
 
 =head2 display()
 
 This is a run mode for Person.
 
-See htdocs/assets/templates/app/office/contacts/web.page.tx for the calling code.
+See htdocs/assets/templates/app/office/contacts/homepage.tx for the calling code.
 
 =head2 get_occupations()
 
 This is a run mode for Person.
 
-See htdocs/assets/templates/app/office/contacts/web.page.tx for the calling code.
+See htdocs/assets/templates/app/office/contacts/homepage.tx for the calling code.
 
 =head2 update()
 
 This is a run mode for Person.
 
-See htdocs/assets/templates/app/office/contacts/web.page.tx for the calling code.
+See htdocs/assets/templates/app/office/contacts/homepage.tx for the calling code.
 
 =head1 FAQ
 
