@@ -3,9 +3,7 @@ package App::Office::Contacts::Controller::Exporter::Report;
 use strict;
 use utf8;
 use warnings;
-use warnings  qw(FATAL utf8);    # Fatalize encoding glitches.
-use open      qw(:std :utf8);    # Undeclared streams in UTF-8.
-use charnames qw(:full :short);  # Unneeded in v5.16.
+use warnings  qw(FATAL utf8); # Fatalize encoding glitches.
 
 use App::Office::Contacts::Util::Validator;
 
@@ -21,7 +19,7 @@ use Sub::Exporter -setup =>
 
 use Try::Tiny;
 
-our $VERSION = '2.01';
+our $VERSION = '2.02';
 
 # -----------------------------------------------
 
@@ -77,7 +75,7 @@ sub display
 		$response = $self -> param('system_error');
 	};
 
-	return encode('utf8', $response);
+	return encode('utf-8', $response);
 
 } # End of display.
 
@@ -121,7 +119,7 @@ Each instance of this class is an L<App::Office::Contacts::Controller>-based obj
 
 This is a run mode for Report.
 
-See htdocs/assets/templates/app/office/contacts/web.page.tx for the calling code.
+See htdocs/assets/templates/app/office/contacts/homepage.tx for the calling code.
 
 =head1 FAQ
 
